@@ -5,13 +5,11 @@ from trytond.pool import PoolMeta
 __all__ = ['Party', 'Address']
 
 
-class Party:
-    __metaclass__ = PoolMeta
+class Party(metaclass=PoolMeta):
     __name__ = 'party.party'
     _history = True
 
 
-class Address:
-    __metaclass__ = PoolMeta
+class Address(metaclass=PoolMeta):
     __name__ = 'party.address'
     _history = True
